<?php

/**
 * @link 			  #
 * @since 			  1.0.0
 * @package 		  Contact_Form_7_WYSIWYG
 *
 * @wordpress-plugin
 * Plugin Name: 	  WYSIWYG Editor for Contact Form 7
 * Plugin URI: 		  https://github.com/DimChtz/contact-form-7-wysiwyg
 * Description: 	  Adds WYSIWYG Editor field for Contact Form 7
 * Version: 		  2.0.2
 * Author: 			  Dimitris Chatzis, Sebastian Weiß
 * Author URI: 		  https://github.com/DimChtz
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       cf7-wysiwyg
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
	die;
}

defined('ABSPATH') || exit;

define('wysiwyg_url', plugin_dir_url(__FILE__));
define('wysiwyg_path', plugin_dir_path(__FILE__));




define('CF7_WYSIWYG_VERSION', '1.0.4');
define('CF7_WYSIWYG_ENV', 'PRODUCTION');
define('CF7_WYSIWYG_PLUGIN_DIR', dirname(__FILE__));
define('CF7_WYSIWYG_PLUGIN_URL', plugin_dir_url(__FILE__));
define('CF7_WYSIWYG_PLUGIN_BASENAME', dirname(plugin_basename(__FILE__)));
define('CF7_WYSIWYG_PLUGIN_INCLUDES', CF7_WYSIWYG_PLUGIN_DIR . '/includes');
define('CF7_WYSIWYG_PLUGIN_TEMPLATES', CF7_WYSIWYG_PLUGIN_DIR . '/templates');
define('CF7_WYSIWYG_PLUGIN_ASSETS', CF7_WYSIWYG_PLUGIN_URL . '/assets');

require_once __DIR__ . '/vendor/autoload.php';
use YahnisElsts\PluginUpdateChecker\v5\PucFactory as CF7_WYSIWYG_PucFactory;

CF7_WYSIWYG_PucFactory::buildUpdateChecker(
	'http://plugins.lightweb-media.de/api?action=get_metadata&slug=wysiwyg-editor-for-contact-form-7', //Metadata URL.
	__FILE__, //Full path to the main plugin file.
	'wysiwyg-editor-for-contact-form-7' //Plugin slug. Usually it's the same as the name of the directory.
);

// Call the bootloader
require_once __DIR__ . '/bootloader.php';

// Remove the default action hooked to wp_enqueue_scripts
remove_action('wp_enqueue_scripts', ['Dimchtz\CF7_WYSIWYG\Modules\Frontend', 'load_scripts']);

// Custom function to load scripts only on specific pages using is_page
function uw_load_scripts_on_specific_pages()
{
	if (is_singular()) {

		global $post;

		if (has_shortcode(get_the_content(), 'contact-form-7')) {
			if (function_exists('wpcf7')) {
				wp_enqueue_media();
				wp_enqueue_editor();

				wp_enqueue_script(
					'wysiwyg-main',
					CF7_WYSIWYG_PLUGIN_ASSETS . '/js/main.frontend.js',
					array('jquery'),
					-1,
					true
				);
			}


		}



	}
}

// Hook the custom function to wp_enqueue_scripts
add_action('wp_enqueue_scripts', 'uw_load_scripts_on_specific_pages');




